@@ -22,9 +22,9 @@ def compute_degree(polynomial: dict):
     return max(len(term) for term in polynomial)
 
 
-def polynomial_validation(polynomial: dict,
-                          num_variables: int,
-                          validate_types: bool = True):
+def polynomial_validation(
+    polynomial: dict, num_variables: int, validate_types: bool = True
+):
     """
 
     Args:
@@ -64,18 +64,19 @@ def polynomial_validation(polynomial: dict,
             assert self.deg is None
             assert self.variables is None
             self.deg = compute_degree(self.poly)
-            self.variables = set(
-                itertools.chain.from_iterable(self.poly.keys()))
+            self.variables = set(itertools.chain.from_iterable(self.poly.keys()))
             if not self.variables.issubset(range(self.num_vars)):
                 raise ValueError(
-                    f'Specified number of variables {self.num_vars} is inconsistent with '
-                    f'the variables in the polynomial.\nExpected variables '
-                    f'to be ints in the range {{0,...,{self.num_vars - 1}}} '
-                    f'but found variables between {min(self.variables)} and '
-                    f'{max(self.variables)} inclusive.')
+                    f"Specified number of variables {self.num_vars} is inconsistent with "
+                    f"the variables in the polynomial.\nExpected variables "
+                    f"to be ints in the range {{0,...,{self.num_vars - 1}}} "
+                    f"but found variables between {min(self.variables)} and "
+                    f"{max(self.variables)} inclusive."
+                )
 
     return pydantic_model_abridge_validation_errors(
         model=_PolynomialValidation,
         max_num_errors=10,
         poly=polynomial,
-        num_vars=num_variables)
+        num_vars=num_variables,
+    )
